/*******************************************************************************
*
*                    ATmega8 Timer 0 with Interrupt
*                    ------------------------------
*
*   Filename:                                    
*   Autor:                  David Kress
*
*   Version:                1.0
*   Date:                   28.1.2013
*   Built with:             ATMEL AVR Studio 4.14 and AVR-GCC; Optimization -01
*
*
*   Clock source:           - Any 1Mhz clock
*
*   Recommended             - High: 0xD9
*   Fuse settings:          - Low:  0xC1
*
*
*
*   Schematic:       ___________________
*                   |      ATMEGA16     |
*          Vcc ---->|Vcc                |
*          Vcc ---->|RESET              |
*                   |                   |
*          GND ---->|GND                |
*                   |                   |
*                   |               PB0 |----> DOUT     
*                   |                   |
*
*******************************************************************************/
#include <avr/io.h>
#include <avr/interrupt.h>

int main(void)
{

    DDRB = 0x01;                      // Setup PB0 as output

    
    TCCR0= (1<<CS02)|(1<<CS00);       // Start Timer 0 with prescaler 1024
    TIMSK= (1<<TOIE0);                // Enable Timer 0 overflow interrupt

    sei();                            // Set the I-bit in SREG

    for(;;);                          // Endless loop;
                                      // main() will never be left

    return 0;                         // This line will never be executed

}


// Interrupt subroutine for Timer0 Overflow interrupt
ISR(TIMER0_OVF_vect) 
{
    PORTB ^= 0x01;                    // Toggle PB0
	                                  // f_PB0 = 1MHz/1042/256/2 = 1.9Hz
} 


